@@ -2,11 +2,10 @@
 # -*- coding: latin-1 -*-
 
 """
-script/cs2both.py
+script/cs2both.py script.
 
 Script that change a CodeSkulptor program
 to run in CodeSkulptor *and* Python SimpleGUICS2Pygame.
-(April 21, 2014)
 
 A file codeskulptor_program.py is copied
 to codeskulptor_program.py.bak before changing.
@@ -25,8 +24,9 @@ Changes made :
 Piece of SimpleGUICS2Pygame.
 https://bitbucket.org/OPiMedia/simpleguics2pygame
 
-GPLv3 --- Copyright (C) 2013, 2014 Olivier Pirson
-http://www.opimedia.be/
+:license: GPLv3 --- Copyright (C) 2013-2014, 2020 Olivier Pirson
+:author: Olivier Pirson --- http://www.opimedia.be/
+:version: May 20, 2020
 """
 
 from __future__ import print_function
@@ -38,46 +38,42 @@ import re
 import sys
 
 
-def main():
-    """
-    Main function.
-    """
+def main():  # pylint: disable=too-many-branches,too-many-statements
+    # type: () -> None
+    """Main function."""
     if (len(sys.argv) != 2) or (sys.argv[1][0] == '-'):
         help_and_exit()
 
-    filename = sys.argv[1]
+    filename = os.path.abspath(os.path.expanduser(sys.argv[1]))
 
     if filename[-3:] != '.py':
         print("! '{}' have not '.py' extension.".format(filename))
 
-        exit(1)
+        exit(1)  # pylint: disable=consider-using-sys-exit
 
     if not os.path.isfile(filename):
         print("! '{}' doesn't exist.".format(filename))
 
-        exit(1)
+        exit(1)  # pylint: disable=consider-using-sys-exit
 
     if os.path.isfile(filename + '.bak'):
         print("! '{}.bak' alread exist.".format(filename))
 
-        exit(1)
+        exit(1)  # pylint: disable=consider-using-sys-exit
 
     # Read
-    infile = open(filename)
-
-    lines = [line.rstrip() for line in infile]
-
-    infile.close()
+    with open(filename) as infile:
+        lines = [line.rstrip() for line in infile]
 
     # Check
     if len(lines) < 2:
         print('"Empty" file.')
 
-        exit()
+        exit()  # pylint: disable=consider-using-sys-exit
 
     add_shebang = lines[0][:2]
-    add_coding = (not re.match(r'#\w*-\*- coding: \W+ -\*-$', lines[0])
-                  and not re.match(r'#\w*-\*- coding: \W+ -\*-$', lines[1]))
+    add_coding = (not re.match(r'#\w*-\*- coding: \W+ -\*-$', lines[0]) and
+                  not re.match(r'#\w*-\*- coding: \W+ -\*-$', lines[1]))
 
     change_import = False
     already_change_import = False
@@ -91,11 +87,11 @@ def main():
     if len(lines) < 2:
         print('"Empty" file.')
 
-        exit()
+        exit()  # pylint: disable=consider-using-sys-exit
 
     for line in lines:
-        if (not already_change_import
-                and re.search(r'^\w*import SimpleGUICS2Pygame', line)):
+        if (not already_change_import and
+                re.search(r'^\w*import SimpleGUICS2Pygame', line)):
             already_change_import = True
 
     if not already_change_import:
@@ -107,46 +103,42 @@ def main():
                           else '')
                 lines[i] = '\n' + indent + ('\n' + indent).join(
                     ("# Automatically modified by 'cs2both.py'",
-                     '# to run in CodeSkulptor *and* standard Python with SimpleGUICS2Pygame:',
+                     '# to run in CodeSkulptor *and* standard Python with SimpleGUICS2Pygame:',  # noqa
                      '# https://bitbucket.org/OPiMedia/simpleguics2pygame',
                      'try:',
                      '    import simplegui',
                      'except ImportError:',
-                     '    import SimpleGUICS2Pygame.simpleguics2pygame as simplegui')) + '\n'
+                     '    import SimpleGUICS2Pygame.simpleguics2pygame as simplegui')) + '\n'  # noqa
 
     # Write
     if add_shebang or add_coding or change_import or end_blank_line:
         os.rename(filename, filename + '.bak')
         print("File copied to {}.bak'".format(filename))
 
-        outfile = (open(filename, mode='w', encoding='latin_1', newline='\n')
-                   if sys.version_info[0] >= 3
-                   else open(filename, mode='w'))
+        with (open(filename, mode='w', encoding='latin_1', newline='\n')
+              if sys.version_info[0] >= 3
+              else open(filename, mode='w')) as outfile:
+            if add_shebang:
+                print('Add shebang.')
+                print('#!/usr/bin/env python', file=outfile)
 
-        if add_shebang:
-            print('Add shebang.')
-            print('#!/usr/bin/env python', file=outfile)
+            if add_coding:
+                print('Add coding latin-1.')
+                print('# -*- coding: latin-1 -*-', file=outfile)
 
-        if add_coding:
-            print('Add coding latin-1.')
-            print('# -*- coding: latin-1 -*-', file=outfile)
+            if change_import:
+                print('Change import simplegui.')
 
-        if change_import:
-            print('Change import simplegui.')
+            if end_blank_line:
+                print('End blank line deleted.')
 
-        if end_blank_line:
-            print('End blank line deleted.')
-
-        print('\n'.join(lines), file=outfile)
-
-        outfile.close()
+            print('\n'.join(lines), file=outfile)
     else:
         print('Nothing changed.')
 
     while lines:
         line = lines.pop()
-        if re.search(r'^\w*f(rame)?\.start\(\)', line):  # f.start()
-                                                         #   or frame.start()
+        if re.search(r'^\w*f(rame)?\.start\(\)', line):  # f.start() or frame.start()  # pylint: disable=no-else-break  # noqa
             break
         elif re.search(r'^\w*[^#]+\.start\(\)', line):   # other .start()
             print('Warning: Maybe a timer is started *after* the start frame.')
@@ -154,7 +146,7 @@ def main():
             break
 
 
-def help_and_exit():
+def help_and_exit():  # type: () -> None
     """
     Print help message on error output
     and exit.
@@ -179,7 +171,7 @@ Changes made :
 - *Try* to check if a timer is started *after* the start frame.
 """, file=sys.stderr)
 
-    exit(1)
+    exit(1)  # pylint: disable=consider-using-sys-exit
 
 
 ########
