@@ -1,7 +1,7 @@
 # -*- coding: latin-1 -*-
 
 """
-simplegui_lib_fps (May 25, 2014)
+simplegui_lib_fps module.
 
 A class to calculate and display FPS (Frames Per Second)
 in SimpleGUI of CodeSkulptor.
@@ -9,14 +9,28 @@ in SimpleGUI of CodeSkulptor.
 Piece of SimpleGUICS2Pygame.
 https://bitbucket.org/OPiMedia/simpleguics2pygame
 
-GPLv3 --- Copyright (C) 2013, 2014 Olivier Pirson
-http://www.opimedia.be/
+:license: GPLv3 --- Copyright (C) 2013-2014, 2020 Olivier Pirson
+:author: Olivier Pirson --- http://www.opimedia.be/
+:version: May 19, 2020
 """
 
+# print('IMPORT', __name__)
+
+
+try:
+    from typing import Optional, Union
+except ImportError:
+    pass
+
+try:
+    import simplegui  # pytype: disable=import-error  # pylint: disable=unused-import  # noqa
+except ImportError:
+    import SimpleGUICS2Pygame.simpleguics2pygame as simplegui  # type: ignore  # pylint: disable=unused-import  # noqa
+
 
 # Class
 ########
-class FPS:
+class FPS:  # pylint: disable=too-many-instance-attributes
     """
     Calculate and display FPS (Frames Per Second).
 
@@ -24,10 +38,12 @@ class FPS:
 
     * Create an instance of FPS: ``fps = FPS()``
     * Start: ``fps.start()``
-    * And put the ``draw_fct()`` in the end of your canvas' draw handler: ``fps.draw_fct(canvas)``
+    * And put the ``draw_fct()``
+      in the end of your canvas' draw handler: ``fps.draw_fct(canvas)``
     """
 
     def __init__(self, x=10, y=10, font_color='Red', font_size=40):
+        # type: (Union[int, float], Union[int, float], str, int) -> None
         """
         Set an instance to calculate FPS and drawing on position (x, y).
 
@@ -36,8 +52,8 @@ class FPS:
         :param font_color: str
         :param font_size: int > 0
         """
-        assert isinstance(x, int) or isinstance(x, float), type(x)
-        assert isinstance(y, int) or isinstance(y, float), type(y)
+        assert isinstance(x, (int, float)), type(x)
+        assert isinstance(y, (int, float)), type(y)
         assert isinstance(font_color, str), type(font_color)
         assert font_size > 0, font_size
 
@@ -46,9 +62,12 @@ class FPS:
         self._x = x
         self._y = y
 
-        self._timer = None
+        self._fps = None  # type: Optional[int]
+        self._nb_frames_drawed = None  # type: Optional[int]
+        self._nb_seconds = None  # type: Optional[int]
+        self._timer = None  # type: Optional[simplegui.Timer]
 
-    def draw_fct(self, canvas):
+    def draw_fct(self, canvas):  # type: (simplegui.Canvas) -> None
         """
         Update the number of frames drawn
         and draw the FPS.
@@ -60,13 +79,15 @@ class FPS:
         :param canvas: simplegui.Canvas
         """
         if self._timer is not None:
+            assert isinstance(self._nb_frames_drawed, int)
+
             self._nb_frames_drawed += 1
 
             canvas.draw_text(str(self._fps),
-                             (self._x, self._y + self._font_size*3//4),
+                             (self._x, self._y + self._font_size * 3 // 4),
                              self._font_size, self._font_color)
 
-    def is_started(self):
+    def is_started(self):  # type: () -> bool
         """
         If FPS is active
         then return True,
@@ -74,7 +95,7 @@ class FPS:
         """
         return self._timer is not None
 
-    def start(self):
+    def start(self):  # type: () -> None
         """
         Start calculation and drawing.
 
@@ -87,28 +108,23 @@ class FPS:
         self._nb_frames_drawed = 0
         self._nb_seconds = 0
 
-        try:
-            from simplegui import create_timer
-        except ImportError:
-            from SimpleGUICS2Pygame.simpleguics2pygame import create_timer
-
         def update():
-            """
-            Update counters.
-            """
+            """Update counters."""
             if self._timer is not None:
-                self._nb_seconds += 1
-                self._fps = int(round(float(self._nb_frames_drawed)
-                                      / self._nb_seconds))
+                assert isinstance(self._fps, int)
+                assert isinstance(self._nb_frames_drawed, int)
+                assert isinstance(self._nb_seconds, int)
 
-        self._timer = create_timer(1000, update)
+                self._nb_seconds += 1
+                self._fps = int(round(float(self._nb_frames_drawed) /
+                                      self._nb_seconds))
+
+        self._timer = simplegui.create_timer(1000, update)
 
         self._timer.start()
 
-    def stop(self):
-        """
-        Stop calculation and drawing.
-        """
+    def stop(self):  # type: () -> None
+        """Stop calculation and drawing."""
         if self._timer is not None:
             self._timer.stop()
             self._timer = None
