@@ -1,31 +1,64 @@
 # -*- coding: latin-1 -*-
 
 """
-simpleplot (September 1st, 2014)
+simpleplot module.
 
 Replace the simpleplot module of CodeSkulptor.
 
 Require matplotlib_
-(`Unofficial Windows Binaries`_)
 (and must be installed separately).
 
+.. warning::
+  With SimpleGUICS2Pygame,
+  if your program is terminated,
+  then windows opened by
+  ``plot_bars()``, ``plot_lines()`` and ``plot_scatter()``
+  will be closed automatically.
+  You can use the specific function ``_block()``
+  to block the program until closing all windows.
+  See Tips_ to run specific code.
+
+.. _Tips: Tips.html
+
 Piece of SimpleGUICS2Pygame.
 https://bitbucket.org/OPiMedia/simpleguics2pygame
 
-GPLv3 --- Copyright (C) 2013, 2014 Olivier Pirson
-http://www.opimedia.be/
+.. _matplotlib: https://matplotlib.org/
 
-.. _matplotlib: http://matplotlib.org/
-.. _`Unofficial Windows Binaries`: http://www.lfd.uci.edu/~gohlke/pythonlibs/#matplotlib
+:license: GPLv3 --- Copyright (C) 2013-2016, 2020 Olivier Pirson
+:author: Olivier Pirson --- http://www.opimedia.be/
+:version: May 20, 2020
 """
 
-try:
-    import matplotlib.pyplot
-except Exception as e:
-    import os
+from __future__ import print_function
 
-    if os.environ.get('READTHEDOCS', None) != 'True':
-        raise Exception('matplotlib not installed! ' + str(e))
+# print('IMPORT', __name__)
+
+
+try:
+    from typing import Dict, Optional, Sequence, Union
+except ImportError:
+    pass
+
+
+try:
+    from matplotlib import __version__ as _MATPLOTLIB_VERSION
+
+    import matplotlib.pyplot
+
+    _MATPLOTLIB_AVAILABLE = True
+    """
+    `True` if matplotlib is available,
+    else `False`.
+    """
+except ImportError:
+    _MATPLOTLIB_AVAILABLE = False
+
+    _MATPLOTLIB_VERSION = None
+    """
+    `matplotlib.__version__` if Pygame is available,
+    else `None`.
+    """
 
 
 #
@@ -49,18 +82,21 @@ Color used for each graph.
 #
 # Functions
 ############
-def _block():
+def _block():  # type: () -> None
     """
     If some plot windows are open
     then block the program until closing all windows.
     **(Not available in SimpleGUI of CodeSkulptor.)**
     """
-    matplotlib.pyplot.show()
+    if _MATPLOTLIB_AVAILABLE:
+        matplotlib.pyplot.show()
 
 
-def plot_bars(framename, width, height, xlabel, ylabel, datasets,
+def plot_bars(framename, width, height,  # pylint: disable=too-many-arguments,too-many-locals  # noqa
+              xlabel, ylabel, datasets,
               legends=None,
               _block=False, _filename=None):
+    # type: (str, int, int, str, str, Union[Sequence, Dict[Union[int, float], Union[int, float]]], Optional[Sequence], bool, Optional[str]) -> None  # noqa
     """
     Open a window titled `framename`
     and plot graphes with `datasets` data
@@ -113,40 +149,48 @@ def plot_bars(framename, width, height, xlabel, ylabel, datasets,
     assert isinstance(xlabel, str), type(xlabel)
     assert isinstance(ylabel, str), type(ylabel)
 
-    assert isinstance(datasets, list) or isinstance(datasets, tuple), \
-        type(datasets)
+    assert isinstance(datasets, (list, tuple)), type(datasets)
     if __debug__:
         for dataset in datasets:
-            assert isinstance(dataset, list) or isinstance(dataset, tuple) \
-                or isinstance(dataset, dict), type(datasets)
+            assert isinstance(dataset, (list, tuple, dict)), type(datasets)
             assert dataset
             for x, y in (dataset.items() if isinstance(dataset, dict)
                          else dataset):
-                assert isinstance(x, int) or isinstance(x, float), (type(x), x)
-                assert isinstance(y, int) or isinstance(y, float), (type(y), y)
+                assert isinstance(x, (int, float)), (type(x), x)
+                assert isinstance(y, (int, float)), (type(y), y)
 
-    assert ((legends is None) or isinstance(legends, list)
-            or isinstance(legends, tuple)), type(legends)
+    assert ((legends is None) or
+            isinstance(legends, (list, tuple))), type(legends)
     assert (legends is None) or (len(legends) == len(datasets)), legends
 
     assert isinstance(_block, bool), type(_block)
     assert (_filename is None) or isinstance(_filename, str), type(_filename)
 
+    if not _MATPLOTLIB_AVAILABLE:
+        from sys import stderr  # pylint: disable=import-outside-toplevel
+
+        print("""Fake 'plot_bars' function
+because matplotlib is not available!
+See https://simpleguics2pygame.readthedocs.io/en/latest/#installation""",
+              file=stderr)
+
+        return
+
     fig = matplotlib.pyplot.figure()
-    fig.set_size_inches(width//fig.get_dpi(), height//fig.get_dpi(),
+    fig.set_size_inches(width // fig.get_dpi(), height // fig.get_dpi(),
                         forward=True)
 
     fig.canvas.set_window_title(framename)
     matplotlib.pyplot.title(framename)
 
-    from os.path import sep
+    from os.path import abspath, expanduser, sep  # pylint: disable=import-outside-toplevel  # noqa
 
     icon_path = __file__.split(sep)[:-1]
     try:
         icon_path.extend(('_img', 'SimpleGUICS2Pygame_32x32.ico'))
         matplotlib.pyplot.get_current_fig_manager().window.wm_iconbitmap(
             sep.join(icon_path))
-    except:
+    except Exception:  # pylint: disable=broad-except
         pass
 
     matplotlib.pyplot.xlabel(xlabel)
@@ -154,12 +198,12 @@ def plot_bars(framename, width, height, xlabel, ylabel, datasets,
 
     matplotlib.pyplot.grid()
 
-    bar_width = 0.8/len(datasets)
+    bar_width = 0.8 / len(datasets)
     for i, dataset in enumerate(datasets):
         bar_lefts, bar_heights = zip(*(sorted(dataset.items())
                                        if isinstance(dataset, dict)
                                        else dataset))
-        matplotlib.pyplot.bar([x + bar_width*i for x in bar_lefts],
+        matplotlib.pyplot.bar([x + bar_width * i for x in bar_lefts],
                               bar_heights,
                               width=bar_width,
                               color=_COLORS[i % len(_COLORS)],
@@ -176,12 +220,15 @@ def plot_bars(framename, width, height, xlabel, ylabel, datasets,
     matplotlib.pyplot.show(block=_block)
 
     if _filename is not None:
+        _filename = abspath(expanduser(_filename))
         matplotlib.pyplot.savefig(_filename)
 
 
-def plot_lines(framename, width, height, xlabel, ylabel, datasets,
+def plot_lines(framename, width, height,  # pylint: disable=too-many-arguments,too-many-locals  # noqa
+               xlabel, ylabel, datasets,
                points=False, legends=None,
                _block=False, _filename=None):
+    # type: (str, int, int, str, str, Union[Sequence, Dict[Union[int, float], Union[int, float]]], bool, Optional[Sequence], bool, Optional[str]) -> None  # noqa
     """
     Open a window titled `framename`
     and plot graphes with `datasets` data
@@ -241,42 +288,50 @@ def plot_lines(framename, width, height, xlabel, ylabel, datasets,
     assert isinstance(xlabel, str), type(xlabel)
     assert isinstance(ylabel, str), type(ylabel)
 
-    assert isinstance(datasets, list) or isinstance(datasets, tuple), \
-        type(datasets)
+    assert isinstance(datasets, (list, tuple)), type(datasets)
     if __debug__:
         for dataset in datasets:
-            assert isinstance(dataset, list) or isinstance(dataset, tuple) \
-                or isinstance(dataset, dict), type(datasets)
+            assert isinstance(dataset, (list, tuple, dict)), type(datasets)
             assert dataset
             for x, y in (dataset.items() if isinstance(dataset, dict)
                          else dataset):
-                assert isinstance(x, int) or isinstance(x, float), (type(x), x)
-                assert isinstance(y, int) or isinstance(y, float), (type(y), y)
+                assert isinstance(x, (int, float)), (type(x), x)
+                assert isinstance(y, (int, float)), (type(y), y)
 
     assert isinstance(points, bool), type(points)
 
-    assert ((legends is None) or isinstance(legends, list)
-            or isinstance(legends, tuple)), type(legends)
+    assert ((legends is None)
+            or isinstance(legends, (list, tuple))), type(legends)
     assert (legends is None) or (len(legends) == len(datasets)), legends
 
     assert isinstance(_block, bool), type(_block)
     assert (_filename is None) or isinstance(_filename, str), type(_filename)
 
+    if not _MATPLOTLIB_AVAILABLE:
+        from sys import stderr  # pylint: disable=import-outside-toplevel
+
+        print("""Fake 'plot_lines' function
+because matplotlib is not available!
+See https://simpleguics2pygame.readthedocs.io/en/latest/#installation""",
+              file=stderr)
+
+        return
+
     fig = matplotlib.pyplot.figure()
-    fig.set_size_inches(width//fig.get_dpi(), height//fig.get_dpi(),
+    fig.set_size_inches(width // fig.get_dpi(), height // fig.get_dpi(),
                         forward=True)
 
     fig.canvas.set_window_title(framename)
     matplotlib.pyplot.title(framename)
 
-    from os.path import sep
+    from os.path import abspath, expanduser, sep  # pylint: disable=import-outside-toplevel  # noqa
 
     icon_path = __file__.split(sep)[:-1]
     try:
         icon_path.extend(('_img', 'SimpleGUICS2Pygame_32x32.ico'))
         matplotlib.pyplot.get_current_fig_manager().window.wm_iconbitmap(
             sep.join(icon_path))
-    except:
+    except Exception:  # pylint: disable=broad-except
         pass
 
     matplotlib.pyplot.xlabel(xlabel)
@@ -302,12 +357,15 @@ def plot_lines(framename, width, height, xlabel, ylabel, datasets,
     matplotlib.pyplot.show(block=_block)
 
     if _filename is not None:
+        _filename = abspath(expanduser(_filename))
         matplotlib.pyplot.savefig(_filename)
 
 
-def plot_scatter(framename, width, height, xlabel, ylabel, datasets,
+def plot_scatter(framename, width, height,  # pylint: disable=too-many-arguments,too-many-locals  # noqa
+                 xlabel, ylabel, datasets,
                  legends=None,
                  _block=False, _filename=None):
+    # type: (str, int, int, str, str, Union[Sequence, Dict[Union[int, float], Union[int, float]]], Optional[Sequence], bool, Optional[str]) -> None  # noqa
     """
     Open a window titled `framename`
     and plot graphes with `datasets` data
@@ -360,40 +418,48 @@ def plot_scatter(framename, width, height, xlabel, ylabel, datasets,
     assert isinstance(xlabel, str), type(xlabel)
     assert isinstance(ylabel, str), type(ylabel)
 
-    assert isinstance(datasets, list) or isinstance(datasets, tuple), \
-        type(datasets)
+    assert isinstance(datasets, (list, tuple)), type(datasets)
     if __debug__:
         for dataset in datasets:
-            assert isinstance(dataset, list) or isinstance(dataset, tuple) \
-                or isinstance(dataset, dict), type(datasets)
+            assert isinstance(dataset, (list, tuple, dict)), type(datasets)
             assert dataset
             for x, y in (dataset.items() if isinstance(dataset, dict)
                          else dataset):
-                assert isinstance(x, int) or isinstance(x, float), (type(x), x)
-                assert isinstance(y, int) or isinstance(y, float), (type(y), y)
+                assert isinstance(x, (int, float)), (type(x), x)
+                assert isinstance(y, (int, float)), (type(y), y)
 
-    assert ((legends is None) or isinstance(legends, list)
-            or isinstance(legends, tuple)), type(legends)
+    assert ((legends is None) or
+            isinstance(legends, (list, tuple))), type(legends)
     assert (legends is None) or (len(legends) == len(datasets)), legends
 
     assert isinstance(_block, bool), type(_block)
     assert (_filename is None) or isinstance(_filename, str), type(_filename)
 
+    if not _MATPLOTLIB_AVAILABLE:
+        from sys import stderr  # pylint: disable=import-outside-toplevel
+
+        print("""Fake 'plot_scatter' function
+because matplotlib is not available!
+See https://simpleguics2pygame.readthedocs.io/en/latest/#installation""",
+              file=stderr)
+
+        return
+
     fig = matplotlib.pyplot.figure()
-    fig.set_size_inches(width//fig.get_dpi(), height//fig.get_dpi(),
+    fig.set_size_inches(width // fig.get_dpi(), height // fig.get_dpi(),
                         forward=True)
 
     fig.canvas.set_window_title(framename)
     matplotlib.pyplot.title(framename)
 
-    from os.path import sep
+    from os.path import abspath, expanduser, sep  # pylint: disable=import-outside-toplevel  # noqa
 
     icon_path = __file__.split(sep)[:-1]
     try:
         icon_path.extend(('_img', 'SimpleGUICS2Pygame_32x32.ico'))
         matplotlib.pyplot.get_current_fig_manager().window.wm_iconbitmap(
             sep.join(icon_path))
-    except:
+    except Exception:  # pylint: disable=broad-except
         pass
 
     matplotlib.pyplot.xlabel(xlabel)
@@ -405,7 +471,7 @@ def plot_scatter(framename, width, height, xlabel, ylabel, datasets,
     xmax = float('-inf')
 
     for i, dataset in enumerate(datasets):
-        xs, ys = zip(*(sorted(dataset.items())
+        xs, ys = zip(*(sorted(dataset.items())  # pylint: disable=invalid-name
                        if isinstance(dataset, dict)
                        else dataset))
         xmin = min(xmin, min(xs))
@@ -424,4 +490,13 @@ def plot_scatter(framename, width, height, xlabel, ylabel, datasets,
     matplotlib.pyplot.show(block=_block)
 
     if _filename is not None:
+        _filename = abspath(expanduser(_filename))
         matplotlib.pyplot.savefig(_filename)
+
+
+# Clean types use by static checking
+if 'Sequence' in dir():
+    del Dict
+    del Optional
+    del Sequence
+    del Union
