@@ -2,45 +2,45 @@
 # -*- coding: latin-1 -*-
 
 """
-Test dir() content. (September 2, 2014)
+Test dir() content.
 
 Piece of SimpleGUICS2Pygame.
 https://bitbucket.org/OPiMedia/simpleguics2pygame
 
-GPLv3 --- Copyright (C) 2013, 2014 Olivier Pirson
-http://www.opimedia.be/
+:license: GPLv3 --- Copyright (C) 2013-2015, 2020 Olivier Pirson
+:author: Olivier Pirson --- http://www.opimedia.be/
+:version: May 21, 2020
 """
 
 from sys import argv
 
 try:
-    import simplegui
-    import codeskulptor
-    import numeric
-    import simpleplot
+    import simplegui  # pytype: disable=import-error
+    import codeskulptor  # pytype: disable=import-error
+    import numeric  # pytype: disable=import-error
+    import simplemap  # not implemented in SimpleGUICS2Pygame  # pytype: disable=import-error  # noqa
+    import simpleplot  # pytype: disable=import-error
 
     SIMPLEGUICS2PYGAME = False
 except ImportError:
-    import SimpleGUICS2Pygame.simpleguics2pygame as simplegui
-    import SimpleGUICS2Pygame.codeskulptor as codeskulptor
-    import SimpleGUICS2Pygame.numeric as numeric
-    import SimpleGUICS2Pygame.simpleplot as simpleplot
+    import SimpleGUICS2Pygame.simpleguics2pygame as simplegui  # type: ignore
+    import SimpleGUICS2Pygame.codeskulptor as codeskulptor  # type: ignore
+    import SimpleGUICS2Pygame.numeric as numeric  # type: ignore
+    import SimpleGUICS2Pygame.simpleplot as simpleplot  # type: ignore
 
     SIMPLEGUICS2PYGAME = True
 
-
 if SIMPLEGUICS2PYGAME:
     from sys import version as python_version
-    from pygame.version import ver as pygame_version
-    from SimpleGUICS2Pygame import _VERSION as GUI_VERSION
+
+    try:
+        from typing import Optional, Sequence
+    except ImportError:
+        pass
 
     PYTHON_VERSION = 'Python ' + python_version.split()[0]
-    PYGAME_VERSION = 'Pygame ' + pygame_version
-    GUI_VERSION = 'SimpleGUICS2Pygame ' + GUI_VERSION
 else:
-    PYTHON_VERSION = 'CodeSkulptor'  # http://www.codeskulptor.org/
-    PYGAME_VERSION = ''
-    GUI_VERSION = 'simplegui'
+    PYTHON_VERSION = 'CodeSkulptor'  # http://www.codeskulptor.org/ or https://py3.codeskulptor.org/  # noqa
 
 
 TEST = 'test dir'
@@ -48,7 +48,7 @@ TEST = 'test dir'
 
 CODESKULPTOR_DIRS = {
     'codeskulptor': ('__name__',
-                     'file2url', 'set_timeout'),
+                     'file2url', 'randomize_iteration', 'set_timeout'),
 
     'numeric': ('__name__',
                 'identity',
@@ -56,7 +56,8 @@ CODESKULPTOR_DIRS = {
     'numeric.Matrix': ('__init__',
                        '__add__', '__getitem__', '__module__', '__mul__',
                        '__setitem__', '__str__', '__sub__',
-                       'abs', 'copy', 'getcol', 'getrow', 'inverse', 'scale',
+                       'abs', 'copy', 'getcol', 'getrow', 'inverse',
+                       'scale',  # no available in CodeSkulptor3
                        'shape', 'summation', 'transpose'),
 
     'simplegui': ('__name__',
@@ -67,6 +68,7 @@ CODESKULPTOR_DIRS = {
                   'create_sound', 'create_timer',
                   'load_image', 'load_sound'),
     'simplegui.Canvas': ('__init__', '__module__',
+                         'draw_arc',  # no available in CodeSkulptor 2
                          'draw_circle', 'draw_image', 'draw_line',
                          'draw_point', 'draw_polygon', 'draw_polyline',
                          'draw_text'),
@@ -74,6 +76,7 @@ CODESKULPTOR_DIRS = {
                           'get_text', 'set_text'),
     'simplegui.Frame': ('__init__', '__module__',
                         'add_button', 'add_input', 'add_label',
+                        'download_canvas_image',  # no available in CodeSkulptor 2, and not in documentation of CodeSkulptor3  # noqa
                         'get_canvas_image', 'get_canvas_textwidth',
                         'set_canvas_background', 'set_draw_handler',
                         'set_keydown_handler', 'set_keyup_handler',
@@ -88,6 +91,10 @@ CODESKULPTOR_DIRS = {
     'simplegui.Timer': ('__init__', '__module__',
                         'get_interval', 'is_running', 'start', 'stop'),
 
+    'simplemap': ('__name__',
+                  'Line', 'Map', 'Marker', 'Rice',
+                  'create_map', 'service'),
+
     'simpleplot': ('__name__',
                    'plot_bars', 'plot_lines', 'plot_scatter')}
 """
@@ -109,6 +116,9 @@ DIRS = {
     'simplegui.TextAreaControl': dir(simplegui.TextAreaControl),
     'simplegui.Timer': dir(simplegui.Timer),
 
+    'simplemap': ([] if SIMPLEGUICS2PYGAME  # not implemented SimpleGUICS2Pygame  # noqa
+                  else dir(simplemap)),
+
     'simpleplot': dir(simpleplot)}
 """
 Results of dir() in this environment
@@ -117,7 +127,7 @@ Results of dir() in this environment
 assert set(CODESKULPTOR_DIRS.keys()) == set(DIRS.keys())
 
 
-different = False
+DIFFERENT = False
 """
 `True` if founded a difference,
 else `False`.
@@ -126,6 +136,7 @@ else `False`.
 
 def print_cmp_seq(a, title_a,
                   b, title_b):
+    # type: (Sequence[str], str, Sequence[str], str) -> None
     """
     Compare two sequences and print difference.
 
@@ -134,14 +145,14 @@ def print_cmp_seq(a, title_a,
     :param b: list or tuple
     :param title_b: str
     """
-    global different
+    global DIFFERENT  # pylint: disable=global-statement
 
-    assert isinstance(a, list) or isinstance(a, tuple), type(a)
+    assert isinstance(a, (list, tuple)), type(a)
     assert isinstance(title_a, str), title_a
-    assert isinstance(b, list) or isinstance(b, tuple), type(b)
+    assert isinstance(b, (list, tuple)), type(b)
     assert isinstance(title_b, str), title_b
 
-    ab = list(set(a).union(b))
+    ab = list(set(a).union(b))  # pylint: disable=invalid-name
     ab.sort()
 
     a_b = set(a).difference(b)
@@ -149,44 +160,45 @@ def print_cmp_seq(a, title_a,
 
     indent = max(max([len(i) for i in a]), len(title_a))
 
-    head = ((title_a + ' '*indent)[:indent]
-            + '\t!= ' + title_b + '\n' + '-'*(indent + 11 + len(title_b)))
+    head = ((title_a + ' ' * indent)[:indent] +
+            '\t!= ' + title_b + '\n' +
+            '-' * (indent + 11 + len(title_b)))  # type: Optional[str]
     for name in ab:
         if name in a_b:
             if head:
                 print(head)
                 head = None
             print(name)
-            different = True
+            DIFFERENT = True
         elif name in b_a:
-            if ((name != '__init__')
-                    and (name[:2] == '__') and (name[-2:] == '__')):
+            if ((name != '__init__') and
+                    (name[:2] == '__') and (name[-2:] == '__')):
                 # Exclude additional special functions
                 continue
 
-            if ((len(argv) == 2)
-                and ((name[0] == '_')
-                     or (name in ('division', 'matplotlib',
-                                  'print_function', 'pygame')))):
+            if ((len(argv) == 2) and
+                    ((name[0] == '_') or
+                     (name in ('division', 'matplotlib',
+                               'print_function', 'pygame')))):
                 # Exclude additional private functions and local directives
                 continue
 
             if head:
                 print(head)
                 head = None
-            print(' '*indent + '\t   ' + name)
-            different = True
+            print(' ' * indent + '\t   ' + name)
+            DIFFERENT = True
 
     if not head:
         print('')
 
 
 # Main
-print('List dir() differences between CodeSkulptor (September 2014) and this "Python":\n')
+print('List dir() differences between CodeSkulptor (May 2020) and this "Python":\n')  # noqa
 
-for k in sorted(CODESKULPTOR_DIRS.keys()):
+for k in sorted(CODESKULPTOR_DIRS):
     print_cmp_seq(CODESKULPTOR_DIRS[k], 'CodeSkulptor ' + k,
                   DIRS[k], PYTHON_VERSION + ' ' + k)
 
-if not different:
+if not DIFFERENT:
     print('No difference.')
